<?php

namespace Drupal\email_tfa\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Define Email TFA form access.
 */
class EmailTfaVerifyAccessCheck implements AccessInterface {

  /**
   * Checks access to access Email TFA form.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The currently logged in account.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account) {
    $temp_store = \Drupal::service('user.private_tempstore')->get('email_tfa');
    if (\Drupal::config('email_tfa.settings')->get('status') == 0) {
      return AccessResult::forbidden();
    }

    if ($temp_store->get('email_tfa_user_verify') == 0 && $account->isAuthenticated()) {
      return AccessResult::allowed();
    }

    return AccessResult::forbidden();

  }

}
