<?php

namespace Drupal\email_tfa\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class TfaConfigForm settings.
 */
class EmailTfaConfigForm extends ConfigFormBase {
  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $config_factory, ModuleHandlerInterface $module_handler) {
    parent::__construct($config_factory);
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'email_tfa_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['email_tfa.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('email_tfa.settings');
    $form['email_tfa_settings'] = [
      '#type' => 'vertical_tabs',
    ];

    $form['email_tfa_settings']['settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Settings'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#group' => 'email_tfa_settings',
      '#weight' => 0,
    ];

    $form['email_tfa_settings']['settings']['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Active'),
      '#default_value' => $config->get('status'),
      '#description' => $this->t("Check to enable Email TFA in your site."),
    ];

    $form['email_tfa_settings']['settings']['routes'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Excluded Routes'),
      '#default_value' => $config->get('routes'),
      '#description' => $this->t("Specify route names. Enter one route per line. The '*' character is a wildcard. An example route is %canonical-wildcard for every entity's canonical view. Prepend the ~ character (tilde) to exclude the route.", [
        '%canonical-wildcard' => 'entity.*.canonical',
      ]),
    ];
    $form['email_tfa_settings']['settings']['timeouts'] = [
      '#type' => 'number',
      '#title' => $this->t('Timeout'),
      '#default_value' => $config->get('timeouts'),
      '#required' => TRUE,
    ];

    $form['email_tfa_settings']['mail'] = [
      '#type' => 'details',
      '#title' => $this->t('Mail'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#group' => 'email_tfa_settings',
      '#weight' => 0,
    ];

    $form['email_tfa_settings']['mail']['subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Email subject'),
      '#default_value' => $config->get('subject'),
      '#required' => TRUE,
    ];

    $form['email_tfa_settings']['mail']['body'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Email body'),
      '#default_value' => $config->get('body'),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $config = $this->configFactory->getEditable('email_tfa.settings');
    $config->set('status', $form_state->getValue('status'))->save();
    $config->set('routes', $form_state->getValue('routes'))->save();
    $config->set('timeouts', $form_state->getValue('timeouts'))->save();
    $config->set('subject', $form_state->getValue('subject'))->save();
    $config->set('body', $form_state->getValue('body'))->save();

    $this->config('email_tfa.settings')->save();
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->getValue('timeouts') < 60) {
      $form_state->setErrorByName('timeouts', $this->t('Must be higher than 60 seconds'));
    }
  }

}
